==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "שגיאה בלתי ידועה",
    "Could not move %s - File with this name already exists" : "לא ניתן להעביר את %s - קובץ בשם הזה כבר קיים",
    "Could not move %s" : "לא ניתן להעביר את %s",
    "No file was uploaded. Unknown error" : "לא הועלה קובץ. טעות בלתי מזוהה.",
    "There is no error, the file uploaded with success" : "לא התרחשה שגיאה, הקובץ הועלה בהצלחה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "הקבצים שנשלחו חורגים מהגודל שצוין בהגדרה upload_max_filesize שבקובץ php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה גדוך מהערך MAX_FILE_SIZE שהוגדר בתופס HTML",
    "The uploaded file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "שום קובץ לא הועלה",
    "Missing a temporary folder" : "תקיה זמנית חסרה",
    "Failed to write to disk" : "הכתיבה לכונן נכשלה",
    "Not enough storage available" : "אין די שטח פנוי באחסון",
    "Upload failed. Could not get file info." : "העלאה נכשלה. לא ניתן להשיג את פרטי הקובץ.",
    "Invalid directory." : "תיקייה שגויה.",
    "Files" : "קבצים",
    "Favorites" : "מועדפים",
    "Home" : "בית",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "Could not get result from server." : "לא ניתן לגשת לתוצאות מהשרת.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "מתבצעת כעת העלאת קבצים. עזיבה של העמוד תבטל את ההעלאה.",
    "{new_name} already exists" : "{new_name} כבר קיים",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Unshare" : "הסר שיתוף",
    "Download" : "הורדה",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Error" : "שגיאה",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "Favorite" : "מועדף",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>changed</strong>" : "קובץ או תיקייה <strong>שונו<strong/>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו<strong/>",
    "You created %1$s" : "יצרת %1$s",
    "%2$s created %1$s" : "%2$s נוצרו %1$s",
    "%1$s was created in a public folder" : "%1$s נוצר בתיקייה ציבורית",
    "You changed %1$s" : "שינית %1$s",
    "%2$s changed %1$s" : "%2$s שונו %1$s",
    "You deleted %1$s" : "מחקת %1$s",
    "%2$s deleted %1$s" : "%2$s נמחקו %1$s",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "File handling" : "טיפול בקבצים",
    "Maximum upload size" : "גודל העלאה מקסימלי",
    "max. possible: " : "המרבי האפשרי: ",
    "Save" : "שמירה",
    "Settings" : "הגדרות",
    "WebDAV" : "WebDAV",
    "New" : "חדש",
    "Text file" : "קובץ טקסט",
    "New folder" : "תיקייה חדשה",
    "Folder" : "תיקייה",
    "Upload" : "העלאה",
    "Cancel upload" : "ביטול ההעלאה",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "Files are being scanned, please wait." : "הקבצים נסרקים, נא להמתין."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "שגיאה בלתי ידועה",
    "Could not move %s - File with this name already exists" : "לא ניתן להעביר את %s - קובץ בשם הזה כבר קיים",
    "Could not move %s" : "לא ניתן להעביר את %s",
    "No file was uploaded. Unknown error" : "לא הועלה קובץ. טעות בלתי מזוהה.",
    "There is no error, the file uploaded with success" : "לא התרחשה שגיאה, הקובץ הועלה בהצלחה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "הקבצים שנשלחו חורגים מהגודל שצוין בהגדרה upload_max_filesize שבקובץ php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה גדוך מהערך MAX_FILE_SIZE שהוגדר בתופס HTML",
    "The uploaded file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "שום קובץ לא הועלה",
    "Missing a temporary folder" : "תקיה זמנית חסרה",
    "Failed to write to disk" : "הכתיבה לכונן נכשלה",
    "Not enough storage available" : "אין די שטח פנוי באחסון",
    "Upload failed. Could not get file info." : "העלאה נכשלה. לא ניתן להשיג את פרטי הקובץ.",
    "Invalid directory." : "תיקייה שגויה.",
    "Files" : "קבצים",
    "Favorites" : "מועדפים",
    "Home" : "בית",
    "Close" : "סגירה",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "Could not get result from server." : "לא ניתן לגשת לתוצאות מהשרת.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "מתבצעת כעת העלאת קבצים. עזיבה של העמוד תבטל את ההעלאה.",
    "Actions" : "פעולות",
    "Download" : "הורדה",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Details" : "פרטים",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Error" : "שגיאה",
    "{new_name} already exists" : "{new_name} כבר קיים",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "New" : "חדש",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "Favorite" : "מועדף",
    "Upload" : "העלאה",
    "Text file" : "קובץ טקסט",
    "Folder" : "תיקייה",
    "New folder" : "תיקייה חדשה",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>changed</strong>" : "קובץ או תיקייה <strong>שונו<strong/>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו<strong/>",
    "You created %1$s" : "יצרת %1$s",
    "%2$s created %1$s" : "%2$s נוצרו %1$s",
    "%1$s was created in a public folder" : "%1$s נוצר בתיקייה ציבורית",
    "You changed %1$s" : "שינית %1$s",
    "%2$s changed %1$s" : "%2$s שונו %1$s",
    "You deleted %1$s" : "מחקת %1$s",
    "%2$s deleted %1$s" : "%2$s נמחקו %1$s",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "File handling" : "טיפול בקבצים",
    "Maximum upload size" : "גודל העלאה מקסימלי",
    "max. possible: " : "המרבי האפשרי: ",
    "Save" : "שמירה",
    "Settings" : "הגדרות",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "ביטול ההעלאה",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "Files are being scanned, please wait." : "הקבצים נסרקים, נא להמתין.",
    "Upload failed. Could not get file info." : "העלאה נכשלה. לא ניתן להשיג את פרטי הקובץ."
},
"nplurals=2; plural=(n != 1);");
